@@ -1,16 +1,17 @@
+#' @export
 # Sets Visibility
 setVisible <- function(jObj, bVisible)
 {
   invisible(.jcall(jObj,,"setVisible",bVisible))
 }
-
+#' @export
 load.class = function(class){
   globenv <- globalenv()
   globenv[[".stv"]] <- .jnew(class); 
   setVisible(globenv[[".stv"]], TRUE)
 }
-
-jgr.removeMenu = function(name) 
+#' @export
+jgr.__removeMenu = function(name) 
 {
  # jgr.removeMenu("Workspace")
     if (!.jgr.works) {
